==> taffybar-4.0.3-46-x86_64.pkg.tar.zst: usr/share/haskell/register/taffybar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.0.3
visibility:             public
id:                     taffybar-4.0.3-7d65wadcZBE9i9gmeXzaS6
key:                    taffybar-4.0.3-7d65wadcZBE9i9gmeXzaS6
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    4ae914681244793e1445c6bac512752a
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.0.3-7d65wadcZBE9i9gmeXzaS6
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig z m zstd lzma pthread jpeg atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 systemd xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/at-spi2-atk/2.0
    /usr/include/at-spi-2.0 /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-3IOmIAI3eC86Rh0e4UN6b1
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    aeson-2.1.2.1-Kzzie09M6AYFH8VDx0mx86
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc base-4.17.2.1
    broadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF bytestring-0.11.5.3
    conduit-1.3.6.1-82jMOxZzolypQFNqeliRy containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    dbus-1.3.1-38oduk7rSWUB3r1pmNfAv0
    dbus-hslogger-0.1.0.1-afepvwMta23PyDE9u3YF4 directory-1.3.7.1
    dyre-0.9.2-6xsWj8cnPnO43rkWvoQDdD
    either-5.0.2-9550az1aJXYCamgHJfPTw3
    enclosed-exceptions-1.0.3-3sIp3mbEKhNCm4Oomo8Dtq filepath-1.4.2.2
    gi-cairo-connector-0.1.1-J3DP7IBS6kRKDlyV4Z5eyt
    gi-cairo-render-0.1.2-BkBngUhVgdyJikxMqmXsq6
    gi-gdk-3.0.26-9VVKOUyOZRFBVjFMTZcCsB
    gi-gdkpixbuf-2.0.31-1qE4l4Z69LJ4u6ybsC8rhy
    gi-gdkx11-3.0.13-zYLj25SUfB2F2yZMrfFFS
    gi-glib-2.0.29-CpaOi5pwLHW6oIB3Meu1dh
    gi-gtk-3.0.39-AWpSqEYwaps1UH74C7XM0K
    gi-gtk-hs-0.3.16-32jmY6ztZ0oIXFFD3w02y1
    gi-pango-1.0.29-2NLBsjFrd6sI23c6ShVMxo
    gtk-sni-tray-0.1.8.1-2GILhxHe56iI5cztuxRayn
    gtk-strut-0.1.3.2-6DCpquCDbKCHInz44sNKHn
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg
    hslogger-1.3.1.2-9r6004OoCOs6RTVCUN7pE1
    http-client-0.7.17-23w6wIj9GbeK9arRJvAmDK
    http-client-tls-0.3.6.3-2hSd1fCBdlWFtn05eObSxT
    http-conduit-2.3.9.1-JdRoao5PYtX9eJVaLJgLLe
    http-types-0.12.4-D2DAVTmHvcDBQ0h7IvaEn9
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz parsec-3.1.16.1
    process-1.6.18.0 rate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    safe-0.3.21-4dOvXTUjyTXF7ZNQNu197N
    scotty-0.22-4Y1W4HRiCo3FifccIlE9t8
    split-0.2.5-1cvcRB3t1btB7X53ioPSfn
    status-notifier-item-0.3.1.0-1q2z9xsj0B4GNmdBwbrmG7 stm-2.5.1.0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    time-units-1.0.0-256CNFELv6i5YiHpTvd1at transformers-0.5.6.2
    tuple-0.3.0.2-5lDoXGUlmHdCDUcHun7JRj unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
    xdg-desktop-entry-0.1.1.2-LAt9jXC626MAihT3PsORul
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG
    xml-helpers-1.0.0-3ETMafV7UcH4BpT6TqDnxm
    xmonad-0.18.0-L4Fp0JoUSc51zY4EwjUoWA

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> taffybar-4.0.3-47-x86_64.pkg.tar.zst: usr/share/haskell/register/taffybar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.0.3
visibility:             public
id:                     taffybar-4.0.3-KBjbHG6HLRY97zPxVsK3L4
key:                    taffybar-4.0.3-KBjbHG6HLRY97zPxVsK3L4
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    33becd78c88937399c1a2a636a29ad89
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.0.3-KBjbHG6HLRY97zPxVsK3L4
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig z m zstd lzma pthread jpeg atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 systemd xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/at-spi2-atk/2.0
    /usr/include/at-spi-2.0 /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-9sjWybj4L1l9wYT9z7KTl5
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    aeson-2.1.2.1-3xjz2RyG2JVHhJgBzFxi7A
    ansi-terminal-1.0-LkJ9SxmfbHcAL1Z7MEt8xc base-4.17.2.1
    broadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF bytestring-0.11.5.3
    conduit-1.3.6.1-D4YiOfvDFG0FSohx4jmvQj containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    dbus-1.3.1-GYvKJnMkvpwIm9pL0hmmUq
    dbus-hslogger-0.1.0.1-Ipne7eLQWh4KAiGpkWYyQ9 directory-1.3.7.1
    dyre-0.9.2-6xsWj8cnPnO43rkWvoQDdD
    either-5.0.2-1qrh2ytujkN7dXMvPhu67j
    enclosed-exceptions-1.0.3-Gi65prcCo7bL7QVO6h7bb0 filepath-1.4.2.2
    gi-cairo-connector-0.1.1-3PU5zLQ9eG296vY3lfZgtl
    gi-cairo-render-0.1.2-IneaYBfsDASKsCTbWzcdMF
    gi-gdk-3.0.26-BKEUxsNuoGz5aM1ys8UdWi
    gi-gdkpixbuf-2.0.31-8GOtg6dDiKH3oXjpqDJ8SH
    gi-gdkx11-3.0.13-G8CstsmQCSBEEtXMWumkpQ
    gi-glib-2.0.29-6CmtwjbrxMILtPFUJgF8FW
    gi-gtk-3.0.39-5NEWN41aYhi9CGSlPPJ1Ea
    gi-gtk-hs-0.3.16-3fOTnBCxusNF82CMk5huSV
    gi-pango-1.0.29-6yBtZS4JqwpF04wXCaukuX
    gtk-sni-tray-0.1.8.1-BdVGrTHI2DgCPHMzXrueqp
    gtk-strut-0.1.3.2-3CCGrWK6nQ9VQblw6dLy5
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg
    hslogger-1.3.1.2-9N4mNhhL4yo6blkcs8hRve
    http-client-0.7.17-AUuOyA54dq3IiMr8FLNnqs
    http-client-tls-0.3.6.3-GzwCW8R8NYVF7bq70CbU2m
    http-conduit-2.3.9.1-4YTerV4Zzbz95yHR1YEFSW
    http-types-0.12.4-GwcjbD6je3aL0GKpFarP8k
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz parsec-3.1.16.1
    process-1.6.18.0 rate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    safe-0.3.21-3UD7yhjS9NI84sQQ1YTdQf
    scotty-0.22-2zSId3tHaxaE6mJ1I0Rkd3
    split-0.2.5-3ghNiOjEzjd4I9aswWcGmY
    status-notifier-item-0.3.1.0-4m1StSWB2Eg7rw1PrSEzs5 stm-2.5.1.0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    time-units-1.0.0-256CNFELv6i5YiHpTvd1at transformers-0.5.6.2
    tuple-0.3.0.2-JTIE98i1kbO9kwHHsF3aEs unix-2.7.3
    utf8-string-1.0.2-7x3IoasPx5wHP6oJo1JvJP
    xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
    xdg-desktop-entry-0.1.1.2-A6d2pO4wgQYIsr47PNqcdB
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG
    xml-helpers-1.0.0-3ETMafV7UcH4BpT6TqDnxm
    xmonad-0.18.0-2ZP2g43Z7zNLwAjyVgBi5D

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
